@@ -1,26 +1,27 @@
 import boto3
+from botocore.client import Config
 
 
 class AwsHelper:
-    def get_client(self, name, aws_region=None):
+    def getClient(self, name, awsRegion=None):
         config = Config(
             retries = dict(
                 max_attempts = 30
             )
         )
-        if aws_region:
-            return boto3.client(name, region_name=aws_region, config=config)
+        if(awsRegion):
+            return boto3.client(name, region_name=awsRegion, config=config)
         else:
             return boto3.client(name, config=config)
 
-
-    def get_resource(self, name, aws_region=None):
+    def getResource(self, name, awsRegion=None):
         config = Config(
             retries = dict(
                 max_attempts = 30
             )
         )
-        if aws_region:
-            return boto3.resource(name, region_name=aws_region, config=config)
+
+        if(awsRegion):
+            return boto3.resource(name, region_name=awsRegion, config=config)
         else:
-            return boto3.resource(name, config=config)
+            return boto3.resource(name, config=config)
\ No newline at end of file
