@@ -1,9 +1,6 @@
-import os
-import json
-import time
-import datetime
 import boto3
-from botocore.exceptions import ClientError
+import csv
+import io
 from amazon_web_services_helpers.aws_helper import AwsHelper
 
 
@@ -55,3 +52,28 @@ class S3Helper:
         s3 = AwsHelper().get_resource('s3', aws_region)
         obj = s3.Object(bucket_name, s3_file_name)
         return obj.get()['Body'].read().decode('utf-8')
+
+    @staticmethod
+    def writeCSV(fieldNames, csvData, bucketName, s3FileName, awsRegion=None):
+        csv_file = io.StringIO()
+        # with open(fileName, 'w') as csv_file:
+        writer = csv.DictWriter(csv_file, fieldnames=fieldNames)
+        writer.writeheader()
+
+        for item in csvData:
+            i = 0
+            row = {}
+            for value in item:
+                row[fieldNames[i]] = value
+                i = i + 1
+            writer.writerow(row)
+        S3Helper.writeToS3(csv_file.getvalue(), bucketName, s3FileName)
+
+    @staticmethod
+    def writeCSVRaw(csvData, bucketName, s3FileName):
+        csv_file = io.StringIO()
+        # with open(fileName, 'w') as csv_file:
+        writer = csv.writer(csv_file)
+        for item in csvData:
+            writer.writerow(item)
+        S3Helper.writeToS3(csv_file.getvalue(), bucketName, s3FileName)
